@@ -7,6 +7,10 @@ import platform
 import os
 
 
+def get_real_executable_path():
+    return os.path.realpath(sys.executable)
+
+
 def verify_path_env_set(force=False):
     config = get_config()
     print(f"PATH: {os.environ['PATH']}")
@@ -34,18 +38,22 @@ def verify_path_env_set(force=False):
     dump_config(config)
 
 
+def get_macos_shell_cfg_file_paths():
+    return [
+        str(Path(os.getenv('HOME')).joinpath(".bash_profile")),
+        str(Path(os.getenv('HOME')).joinpath(".bashrc")),
+        str(Path(os.getenv('HOME')).joinpath(".zshrc")),
+    ]
+
+
 def macos_runner():
-    python_scripts_dir = str(Path(sys.executable).parent)
-    addition = f"""
-    \n# Setting PATH for Python
-    \nPATH="{python_scripts_dir}:${{PATH}}"
-    \nexport PATH
-    \n
-    """
-    file_p = str(Path(os.getenv('HOME')).joinpath(".bash_profile"))
-    print(f"Adding {addition} to {file_p}")
-    with open(file_p, 'a') as fobj:
-        fobj.write(addition)
+    print(f"B")
+    python_scripts_dir = str(Path(get_real_executable_path()).parent)
+    addition = f'\n# Setting PATH for Python\nPATH="{python_scripts_dir}:${{PATH}}"\nexport PATH\n'
+    for cfg_file_path in get_macos_shell_cfg_file_paths():
+        print(f"Adding {addition} to {cfg_file_path}")
+        with open(cfg_file_path, 'a') as fobj:
+            fobj.write(addition)
 
 
 def windows_runner():
