@@ -17,6 +17,12 @@ def get_config():
     return config
 
 
+def get_config_as_str():
+    if os.path.exists(USER_CONFIG_PATH):
+        with open(USER_CONFIG_PATH) as fobj:
+            return fobj.read()
+
+
 def dump_config(config):
     os.makedirs(USER_CONFIG_DIR_PATH, exist_ok=True)
     with open(USER_CONFIG_PATH, 'w') as configfile:
